/*
 * sat68kdb: Sega Saturn MC68EC000 Debugger
 * Bart Trzynadlowski
 */

/*
 * defs_sh2.h
 */


/*
 * Basic Data Types
 */

typedef unsigned char           BYTE;
typedef unsigned short          WORD;
typedef unsigned int            LONG;


/*
 * General Definitions
 */

#define DELAY_VALUE             0x1000


/*
 * SMPC Addresses
 */

#define SMPC_ADDR_BASE          0x20100000
#define SMPC_ADDR_COMREG        (SMPC_ADDR_BASE + 0x1f)
#define SMPC_ADDR_SR            (SMPC_ADDR_BASE + 0x61)
#define SMPC_ADDR_SF            (SMPC_ADDR_BASE + 0x63)


/*
 * SMPC Commands
 */

#define SMPC_CMND_SNDON         6
#define SMPC_CMND_SNDOFF        7
#define SMPC_CMND_SYSRES        0xd


/*
 * SCSP Addresses
 */

#define SCSP_ADDR_BASE          0x25A00000
#define SCSP_ADDR_CTRL          (SCSP_ADDR_BASE + 0x100400)
#define SCSP_ADDR_SCIEB         (SCSP_ADDR_BASE + 0x10041e)
#define SCSP_ADDR_SCIPD         (SCSP_ADDR_BASE + 0x100420)
#define SCSP_ADDR_SCIRE         (SCSP_ADDR_BASE + 0x100422)
#define SCSP_ADDR_SCILV0        (SCSP_ADDR_BASE + 0x100424)
#define SCSP_ADDR_SCILV1        (SCSP_ADDR_BASE + 0x100426)
#define SCSP_ADDR_SCILV2        (SCSP_ADDR_BASE + 0x100428)


/*
 * PAR Addresses
 */

#define PAR_ADDR_READ           0x22180001
#define PAR_ADDR_WRITE          0x22080001
#define PAR_ADDR_FLAG           0x22100001


/*
 * MC68EC000 Driver Communication Addresses
 */

#define DRIV68K_ADDR_STARTSIG   (SCSP_ADDR_BASE + 0x7fff2)
#define DRIV68K_ADDR_READY      (SCSP_ADDR_BASE + 0x7fff4)
#define DRIV68K_ADDR_COMMAND    (SCSP_ADDR_BASE + 0x7fff6)
#define DRIV68K_ADDR_DATA       (SCSP_ADDR_BASE + 0x7fff8)
#define DRIV68K_ADDR_DATA2      (SCSP_ADDR_BASE + 0x7fffc)


/*
 * Debugger Commands
 */

#define CMND_TRACE              1
#define CMND_READPC             2
#define CMND_READREG            3
#define CMND_WRITEREG           4
#define CMND_READSR             5
#define CMND_WRITESR            6
#define CMND_WRITEPC            7
#define CMND_READXSP            8

#define CMND_READMEMB           0xf9
#define CMND_WRITEMEMB          0xfa
#define CMND_READMEMW           0xfb
#define CMND_WRITEMEMW          0xfc
#define CMND_READMEML           0xfd
#define CMND_WRITEMEML          0xfe
#define CMND_RESET              0xff

